@@ -1,5 +1,5 @@
 /*
- *     Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
+ *     Copyright (c) 2012-2016 CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,9 +19,9 @@
  *
  */
 
-/*global document, LayoutManagerFactory, gettext, interpolate, StyledElements, Wirecloud */
+/* globals StyledElements, Wirecloud */
 
-(function () {
+(function (se, utils) {
 
     "use strict";
 
@@ -30,10 +30,11 @@
             return;
         }
 
-        this.builder = new StyledElements.GUIBuilder();
+        this.builder = new se.GUIBuilder();
         this.catalogue_view = catalogue_view;
         this.structure_template = resource_template;
-        this.error_template = '<s:styledgui xmlns:s="http://wirecloud.conwet.fi.upm.es/StyledElements" xmlns:t="http://wirecloud.conwet.fi.upm.es/Template" xmlns="http://www.w3.org/1999/xhtml"><div class="alert alert-block alert-error"><t:message/></div></s:styledgui>';
+        this.error_template = this.builder.DEFAULT_OPENING + '<div class="alert alert-error"><t:message/></div>' + this.builder.DEFAULT_CLOSING;
+        this.info_template = this.builder.DEFAULT_OPENING + '<div class="alert alert-info"><t:message/></div>' + this.builder.DEFAULT_CLOSING;
         this.container = container;
         if (extra_context != null && (typeof extra_context === 'object' || typeof extra_context === 'function')) {
             this.extra_context = extra_context;
@@ -42,14 +43,25 @@
         }
     };
 
-    ResourcePainter.prototype.setError = function setError(message) {
-        this.container.clear();
+    ResourcePainter.prototype.paintInfo = function paintError(message, context) {
+        if (context != null) {
+            message = this.builder.parse(this.builder.DEFAULT_OPENING + message + this.builder.DEFAULT_CLOSING, context);
+        }
 
-        var contents = this.builder.parse(this.error_template, {
+        return this.builder.parse(this.info_template, {
             'message': message
         });
+    };
 
-        this.container.appendChild(contents);
+    ResourcePainter.prototype.paintError = function paintError(message) {
+        return this.builder.parse(this.error_template, {
+            'message': message
+        });
+    };
+
+    ResourcePainter.prototype.setError = function setError(message) {
+        this.container.clear();
+        this.container.appendChild(this.paintError(message));
     };
 
     ResourcePainter.prototype.paint = function paint(resource) {
@@ -58,23 +70,27 @@
         if (typeof this.extra_context === 'function') {
             extra_context = this.extra_context(resource);
         } else {
-            extra_context = Wirecloud.Utils.clone(this.extra_context);
+            extra_context = utils.clone(this.extra_context);
         }
 
-        if (resource.license != null && resource.license != '') {
+        if (resource.license != null && resource.license !== '') {
             license_text = resource.license;
         } else {
             license_text = 'N/A';
         }
 
-        context = Wirecloud.Utils.merge(extra_context, {
-            'displayname': resource.displayname,
+        context = utils.merge(extra_context, {
+            'title': resource.title,
             'name': resource.name,
             'internalname': resource.uri,
             'vendor': resource.vendor,
-            'version': resource.version.text,
-            'authors': resource.authors,
+            'version': resource.version,
+            'authors': this.get_people_list.bind(null, resource.authors),
+            'contributors': this.get_people_list.bind(null, resource.contributors),
             'description': resource.description,
+            'longdescription': function () {
+                return new se.Fragment(resource.longdescription);
+            },
             'type': function () {
                 var label = document.createElement('div');
                 label.textContent = resource.type;
@@ -96,32 +112,40 @@
 
                 return label;
             },
-            'lastupdate': function () { return resource.date.strftime('%x'); },
-            'doc': function () {
-                var button;
-
-                button = new StyledElements.StyledButton({
-                    'plain': true,
-                    'class': 'icon-doc',
-                    'title': gettext('Documentation')
-                });
-                button.addEventListener('click', function () {
-                    window.open(resource.doc_url, '_blank');
-                });
-
-                return button;
-            },
+            'lastupdate': function () { return moment(resource.date).fromNow(); },
             'home': function () {
                 var button;
 
-                button = new StyledElements.StyledButton({
-                    'plain': true,
-                    'class': 'icon-home',
-                    'title': gettext('Home page')
+                button = new se.Button({
+                    plain: true,
+                    class: 'fa fa-home',
+                    title: utils.gettext('Home page')
                 });
-                button.addEventListener('click', function () {
-                    window.open(resource.doc_url, '_blank');
+                if (resource.homepage != null && resource.homepage !== '') {
+                    button.addEventListener('click', function () {
+                        window.open(resource.homepage, '_blank');
+                    });
+                } else {
+                    button.disable();
+                }
+
+                return button;
+            },
+            'issuetracker': function () {
+                var button;
+
+                button = new se.Button({
+                    plain: true,
+                    class: 'fa fa-bug',
+                    title: utils.gettext('Issue tracker')
                 });
+                if (resource.issuetracker != null && resource.issuetracker !== '') {
+                    button.addEventListener('click', function () {
+                        window.open(resource.issuetracker, '_blank');
+                    });
+                } else {
+                    button.disable();
+                }
 
                 return button;
             },
@@ -129,13 +153,13 @@
             'license_home': function () {
                 var button;
 
-                button = new StyledElements.StyledButton({
-                    'plain': true,
-                    'class': 'icon-legal',
-                    'title': gettext('License details')
+                button = new se.Button({
+                    plain: true,
+                    class: 'fa fa-legal',
+                    title: utils.gettext('License details')
                 });
 
-                if (resource.licenseurl != null && resource.licenseurl != '') {
+                if (resource.licenseurl != null && resource.licenseurl !== '') {
                     button.addEventListener('click', function () {
                         window.open(resource.licenseurl, '_blank');
                     });
@@ -146,111 +170,44 @@
                 return button;
             },
             'rating': this.get_popularity_html.bind(this, resource.rating),
-            'mainbutton': function () {
-                var button, local_catalogue_view;
-
-                local_catalogue_view = LayoutManagerFactory.getInstance().viewsByName.marketplace.viewsByName.local;
-
-                if (!this.catalogue_view.catalogue.is_purchased(this.resource) && ['widget', 'operator', 'mashup', 'pack'].indexOf(this.resource.type) !== -1) {
-                    button = new StyledElements.StyledButton({
-                        'class': 'mainbutton btn-success',
-                        'text': gettext('Buy')
-                    });
-                    button.addEventListener('click', this.catalogue_view.createUserCommand('buy', this.resource));
-                    return button;
-                }
-
-                if (this.resource.type === 'operator') {
-
-                    if (Wirecloud.LocalCatalogue.resourceExists(this.resource)) {
-                        button = new StyledElements.StyledButton({
-                            'class': 'btn-danger',
-                            'text': gettext('Uninstall')
-                        });
-                        button.addEventListener('click', local_catalogue_view.createUserCommand('uninstall', this.resource, this.catalogue_view));
-                    } else {
-
-                        button = new StyledElements.StyledButton({
-                            'text': gettext('Install')
-                        });
-
-                        button.addEventListener('click', local_catalogue_view.createUserCommand('install', this.resource, this.catalogue_view));
-                    }
-                } else if (this.catalogue_view.catalogue === Wirecloud.LocalCatalogue) {
-                    switch (this.resource.type) {
-                    case 'mashup':
-                    case 'widget':
-                        button = new StyledElements.StyledButton({
-                            'class': 'instantiate_button',
-                            'text': gettext('Add to workspace')
-                        });
-                        button.addEventListener('click', this.catalogue_view.createUserCommand('instantiate', this.resource));
-                        break;
-                    default:
-                        button = new StyledElements.StyledButton({text: gettext('Download')});
-                        button.addEventListener('click', function (resource) {
-                            window.open(resource.description_url, '_blank');
-                        }.bind(null, this.resource));
-                    }
-                } else {
-                    if (Wirecloud.LocalCatalogue.resourceExists(this.resource)) {
-                        button = new StyledElements.StyledButton({
-                            'class': 'btn-danger',
-                            'text': gettext('Uninstall')
-                        });
-                        button.addEventListener('click', local_catalogue_view.createUserCommand('uninstall', this.resource, this.catalogue_view));
-                    } else if (['widget', 'operator', 'mashup'].indexOf(this.resource.type) != -1) {
-                        button = new StyledElements.StyledButton({
-                            'text': gettext('Install')
-                        });
-
-                        button.addEventListener('click', local_catalogue_view.createUserCommand('install', this.resource, this.catalogue_view));
-                    } else {
-                        button = new StyledElements.StyledButton({
-                            'text': gettext('Details')
-                        });
-
-                        button.addEventListener('click', this.catalogue_view.createUserCommand('showDetails', this.resource));
-                    }
-                }
-                button.addClassName('mainbutton btn-primary');
-                return button;
-            }.bind({catalogue_view: this.catalogue_view, resource: resource}),
             'image': function () {
                 var image = document.createElement('img');
-                image.onerror = function (event) {
-                    event.target.src = '/static/images/noimage.png';
-                };
-                image.src = resource.image;
+                image.className = 'wc-resource-img';
+
+                if (resource.image) {
+                    image.onerror = onImageError;
+                    setTimeout(() => {image.src = resource.image;});
+                } else {
+                    setTimeout(onImageError.bind(null, {target: image}), 0);
+                }
+
                 return image;
             },
             'tags': function (options) {
                 return this.painter.renderTagList(this.resource, options.max);
             }.bind({painter: this, resource: resource}),
             'advancedops': this.renderAdvancedOperations.bind(this, resource),
-            'uploader': function () {
-                if (resource.uploader != null) {
-                    return resource.uploader;
-                } else {
-                    return gettext('Anonymous');
-                }
-            },
+            'size': utils.formatSize.bind(this, resource.size),
             'versions': function () {
                 var versions = resource.getAllVersions().map(function (version) { return 'v' + version.text; });
                 return versions.join(', ');
             }
         });
 
-        resource_element = this.builder.parse(this.structure_template, context);
+        resource_element = this.builder.parse(this.structure_template, context, resource);
 
-        // TODO "Show details"
+        // TODO "Show details" & tooltip
         for (i = 0; i < resource_element.elements.length; i += 1) {
-            if (!Wirecloud.Utils.XML.isElement(resource_element.elements[i])) {
+            if (!(resource_element.elements[i] instanceof Element)) {
                 continue;
             }
-            this.create_simple_command(resource_element.elements[i], '.click_for_details', 'click', this.catalogue_view.createUserCommand('showDetails', resource));
-            if (resource_element.elements[i].classList.contains('click_for_details')) {
-                resource_element.elements[i].addEventListener('click', this.catalogue_view.createUserCommand('showDetails', resource));
+            if (this.catalogue_view) {
+                this.create_simple_command(resource_element.elements[i], '.click_for_details', 'click', this.catalogue_view.createUserCommand('showDetails', resource));
+            }
+            var title_element = resource_element.elements[i].querySelector('.title-tooltip');
+            if (title_element != null) {
+                var tooltip = new se.Tooltip({content: resource.title, placement: ['top', 'bottom', 'right', 'left']});
+                tooltip.bind(title_element);
             }
         }
 
@@ -258,49 +215,70 @@
     };
 
     ResourcePainter.prototype.renderAdvancedOperations = function renderAdvancedOperations(resource) {
-        var button, fragment = new StyledElements.Fragment();
+        var button, fragment = new se.Fragment();
 
-        button = new StyledElements.StyledButton({
-            'text': gettext('Download')
+        button = new se.Button({
+            'text': utils.gettext('Download')
         });
         button.addEventListener('click', function () {
             window.open(resource.description_url, '_blank');
         });
         fragment.appendChild(button);
 
+        if (resource.type === 'widget') {
+            button = new se.Button({
+                'text': utils.gettext('Add to workspace')
+            });
+            button.addEventListener('click', function () {
+                Wirecloud.UserInterfaceManager.changeCurrentView('workspace');
+                var local_widget = Wirecloud.LocalCatalogue.getResource(resource.vendor, resource.name, resource.version);
+                Wirecloud.activeWorkspace.view.activeTab.createWidget(local_widget);
+            });
+            fragment.appendChild(button);
+        }
+
         if (this.catalogue_view.catalogue === Wirecloud.LocalCatalogue) {
-            button = new StyledElements.StyledButton({
-                'text': gettext('Publish')
+            button = new se.Button({
+                'text': utils.gettext('Publish')
             });
             button.addEventListener('click', this.catalogue_view.createUserCommand('publishOtherMarket', resource));
             fragment.appendChild(button);
         }
 
         if (Wirecloud.LocalCatalogue.resourceExists(resource) && resource.isAllow('uninstall')) {
-            var local_catalogue_view = LayoutManagerFactory.getInstance().viewsByName.marketplace.viewsByName.local;
-            button = new StyledElements.StyledButton({
+            var local_catalogue_view = Wirecloud.UserInterfaceManager.views.myresources;
+            button = new se.Button({
                 'class': 'btn-danger',
-                'text': gettext('Uninstall')
+                'text': utils.gettext('Uninstall')
             });
             button.addEventListener('click', local_catalogue_view.createUserCommand('uninstall', resource, this.catalogue_view));
             fragment.appendChild(button);
         }
 
-        if (resource.isAllow('delete')) {
-            button = new StyledElements.StyledButton({
+        if ((resource.getAllVersions().length > 1) && resource.isAllow('uninstall-all')) {
+            button = new se.Button({
                 'class': 'btn-danger',
-                'text': gettext('Delete')
+                'text': utils.gettext('Uninstall all versions')
+            });
+            button.addEventListener('click', this.catalogue_view.createUserCommand('uninstallall', resource, this.catalogue_view));
+            fragment.appendChild(button);
+        }
+
+        if (resource.isAllow('delete')) {
+            button = new se.Button({
+                'class': 'btn-danger',
+                'text': utils.gettext('Delete')
             });
             button.addEventListener('click', this.catalogue_view.createUserCommand('delete', resource));
             fragment.appendChild(button);
         }
 
         if ((resource.getAllVersions().length > 1) && resource.isAllow('delete-all')) {
-            button = new StyledElements.StyledButton({
+            button = new se.Button({
                 'class': 'btn-danger',
-                'text': gettext('Delete all versions')
+                'text': utils.gettext('Delete all versions')
             });
-            button.addEventListener('click', this.catalogue_view.createUserCommand('delete', resource));
+            button.addEventListener('click', this.catalogue_view.createUserCommand('deleteall', resource));
             fragment.appendChild(button);
         }
 
@@ -310,7 +288,7 @@
     ResourcePainter.prototype.renderTagList = function renderTagList(resource, listener, max) {
         var i, fragment, tags, tag, tag_element, len;
 
-        fragment = new StyledElements.Fragment();
+        fragment = new se.Fragment();
 
         tags = resource.tags.slice();
         tags = tags.sort(function (a, b) {
@@ -334,18 +312,50 @@
     };
 
     ResourcePainter.prototype.create_simple_command = function (element, selector, _event, handler, required) {
-        var i, elements = element.querySelectorAll(selector);
+        var i, elements, root_matches;
 
-        if (required && elements.length < 1) {
+        elements = element.querySelectorAll(selector);
+        root_matches = element.matches(selector);
+
+        if (required && elements.length < 1 && !root_matches) {
             throw new Error();
         }
 
+        if (root_matches) {
+            element.addEventListener(_event, handler);
+        }
+
         for (i = 0; i < elements.length; i += 1) {
             elements[i].addEventListener(_event, handler);
         }
     };
 
-    ResourcePainter.prototype.get_popularity_html = function (popularity) {
+    ResourcePainter.prototype.get_people_list = function get_people_list(people, options) {
+        var i, fragment, dd;
+
+        if (people.length === 0) {
+            dd = document.createElement('dd');
+            if (options.class) {
+                dd.className = options.class;
+            }
+            dd.textContent = utils.gettext('N/A');
+            return dd;
+        }
+        fragment = new se.Fragment();
+
+        for (i = 0; i < people.length; i++) {
+            dd = document.createElement('dd');
+            if (options.class) {
+                dd.className = options.class;
+            }
+            dd.textContent = people[i].name;
+            fragment.appendChild(dd);
+        }
+
+        return fragment;
+    };
+
+    ResourcePainter.prototype.get_popularity_html = function get_popularity_html(popularity) {
         var on_stars, md_star, off_stars, stars, star, i;
 
         if (popularity == null || popularity < 1) {
@@ -386,5 +396,11 @@
         return stars;
     };
 
+    var onImageError = function onImageError(event) {
+        event.target.parentElement.classList.add('se-thumbnail-missing');
+        event.target.parentElement.textContent = utils.gettext('No image available');
+    };
+
     Wirecloud.ui.ResourcePainter = ResourcePainter;
-})();
+
+})(StyledElements, Wirecloud.Utils);
