@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013 CoNWeT Lab., Universidad Politécnica de Madrid
+# Copyright (c) 2013-2017 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
@@ -20,7 +20,9 @@
 from optparse import make_option
 import os
 import subprocess
+import sys
 
+import django
 from django.core.management.base import CommandError
 from django.core.management.commands.startproject import Command
 from django.utils.safestring import mark_safe
@@ -29,8 +31,12 @@ import wirecloud.commons
 from wirecloud.commons.utils.commands import BaseCommand
 
 
-def exec_external_cmd(cmd):
-    result = subprocess.call(cmd, shell=True)
+def exec_external_python_cmd(cmd):
+    if sys.executable in ('', None):
+        python_executable = 'python'
+    else:
+        python_executable = sys.executable
+    result = subprocess.call(python_executable + ' ' + cmd, shell=True)
     if result:
         raise CommandError('Error executing external command')
 
@@ -39,13 +45,17 @@ class StartprojectCommand(BaseCommand):
 
     args = "[name] [optional destination directory]"
     option_list = BaseCommand.option_list + (
-        make_option('-t', '--type',
+        make_option(
+            '-t', '--type',
             action='store',
             dest='type',
-            default='platform'),
-        make_option('-q', '--quick-start',
+            default='platform'
+        ),
+        make_option(
+            '-q', '--quick-start',
             action='store_true',
-            dest='quick_start'),
+            dest='quick_start'
+        ),
     )
 
     def handle(self, project_name=None, target=None, *args, **options):
@@ -55,12 +65,12 @@ class StartprojectCommand(BaseCommand):
         if options['type'] not in ('platform', 'catalogue'):
             raise CommandError("invalid project type")
 
-        template = os.path.join(os.path.dirname(wirecloud.commons.__file__), 'conf', options['type']  + '_project_template')
+        template = os.path.join(os.path.dirname(wirecloud.commons.__file__), 'conf', options['type'] + '_project_template')
         internal_options = {
             'template': template,
             'extensions': ('py',),
             'files': [],
-            'verbosity': options.get('verbosity'),
+            'verbosity': int(options.get('verbosity')),
             'db_engine': mark_safe("'django.db.backends.'"),
             'db_name': mark_safe("''"),
         }
@@ -70,12 +80,16 @@ class StartprojectCommand(BaseCommand):
             internal_options['db_name'] = mark_safe("path.join(BASEDIR, '%s.db')" % project_name)
 
         command = Command()
-        command.handle(project_name, target, *(), **internal_options)
+        if django.VERSION[1] >= 8:
+            internal_options.update({"name": project_name, "directory": target})
+            command.handle(**internal_options)
+        else:
+            command.handle(project_name, target, *(), **internal_options)
 
         if options['quick_start']:
 
             os.chdir(project_name)
-            exec_external_cmd('python manage.py syncdb --migrate --noinput')
-            exec_external_cmd('python manage.py loaddata wirecloud_quick_start')
-            exec_external_cmd('python manage.py collectstatic --noinput')
-            exec_external_cmd('python manage.py compress --force')
+            exec_external_python_cmd('manage.py migrate --noinput')
+            exec_external_python_cmd('manage.py populate')
+            exec_external_python_cmd('manage.py loaddata wirecloud_quick_start')
+            exec_external_python_cmd('manage.py collectstatic --noinput')
