@@ -3,7 +3,7 @@
 
 from os import path
 from wirecloud.commons.utils.conf import load_default_wirecloud_conf
-from wirecloud.commons.utils.urlresolvers import reverse_lazy
+from django.core.urlresolvers import reverse_lazy
 
 DEBUG = False
 BASEDIR = path.dirname(path.abspath(__file__))
@@ -29,7 +29,6 @@ DATABASES = {
     }
 }
 
-# This setting has only effect in DJango 1.5+
 # Hosts/domain names that are valid for this site; required if DEBUG is False
 # See https://docs.djangoproject.com/en/1.5/ref/settings/#allowed-hosts
 ALLOWED_HOSTS = ['*']
@@ -98,22 +97,10 @@ ROOT_URLCONF = '{{ project_name }}.urls'
 WSGI_APPLICATION = '{{ project_name }}.wsgi.application'
 
 INSTALLED_APPS += (
-    #'django.contrib.sites',
+    # 'django.contrib.sites',
     'wirecloud.oauth2provider',
 )
 
-TEMPLATE_CONTEXT_PROCESSORS = (
-    'django.contrib.auth.context_processors.auth',
-    'django.core.context_processors.debug',
-    'django.core.context_processors.i18n',
-    'django.core.context_processors.media',
-    'django.core.context_processors.request',
-    'django.core.context_processors.static',
-    'django.core.context_processors.tz',
-    'django.contrib.messages.context_processors.messages',
-    'wirecloud.platform.themes.active_theme_context_processor',
-)
-
 # Login/logout URLs
 LOGIN_URL = reverse_lazy('login')
 LOGOUT_URL = reverse_lazy('wirecloud.root')
