@@ -1,6 +1,28 @@
-/*global StyledElements, Wirecloud*/
+/*
+ *     Copyright (c) 2011-2016 CoNWeT Lab., Universidad Politécnica de Madrid
+ *
+ *     This file is part of Wirecloud Platform.
+ *
+ *     Wirecloud Platform is free software: you can redistribute it and/or
+ *     modify it under the terms of the GNU Affero General Public License as
+ *     published by the Free Software Foundation, either version 3 of the
+ *     License, or (at your option) any later version.
+ *
+ *     Wirecloud is distributed in the hope that it will be useful, but WITHOUT
+ *     ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ *     FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public
+ *     License for more details.
+ *
+ *     You should have received a copy of the GNU Affero General Public License
+ *     along with Wirecloud Platform.  If not, see
+ *     <http://www.gnu.org/licenses/>.
+ *
+ */
 
-(function () {
+/* globals StyledElements */
+
+
+(function (utils) {
 
     "use strict";
 
@@ -10,18 +32,20 @@
     var BorderLayout = function BorderLayout(options) {
         StyledElements.StyledElement.call(this, []);
 
-        options = Wirecloud.Utils.merge({
+        options = utils.merge({
             'class': ''
         }, options);
 
         this.wrapperElement = document.createElement('div');
-        this.wrapperElement.className = Wirecloud.Utils.appendWord(options['class'], "border_layout");
+        this.wrapperElement.className = utils.appendWord(options.class, "se-border-layout");
 
-        this.north = new StyledElements.Container({'class': 'north_container'});
-        this.west = new StyledElements.Container({'class': 'west_container'});
-        this.center = new StyledElements.Container({'class': 'center_container'});
-        this.east = new StyledElements.Container({'class': 'east_container'});
-        this.south = new StyledElements.Container({'class': 'south_container'});
+        Object.defineProperties(this, {
+            north: {value: new StyledElements.Container({'class': 'se-bl-north-container'})},
+            west: {value: new StyledElements.Container({'class': 'se-bl-west-container'})},
+            center: {value: new StyledElements.Container({'class': 'se-bl-center-container'})},
+            east: {value: new StyledElements.Container({'class': 'se-bl-east-container'})},
+            south: {value: new StyledElements.Container({'class': 'se-bl-south-container'})}
+        });
 
         this.north.insertInto(this.wrapperElement);
         this.west.insertInto(this.wrapperElement);
@@ -29,11 +53,11 @@
         this.east.insertInto(this.wrapperElement);
         this.south.insertInto(this.wrapperElement);
     };
-    BorderLayout.prototype = new StyledElements.StyledElement();
+    utils.inherit(BorderLayout, StyledElements.StyledElement);
 
     BorderLayout.prototype.repaint = function repaint(temporal) {
         var usableArea = {
-            'width' : this.wrapperElement.offsetWidth,
+            'width': this.wrapperElement.offsetWidth,
             'height': this.wrapperElement.offsetHeight
         };
 
@@ -91,4 +115,5 @@
     };
 
     StyledElements.BorderLayout = BorderLayout;
-})();
+
+})(StyledElements.Utils);
