@@ -1,5 +1,5 @@
 /*
- *     (C) Copyright 2013 Universidad Politécnica de Madrid
+ *     Copyright (c) 2013-2015 CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,9 +19,12 @@
  *
  */
 
-/*global Wirecloud*/
+/* globals StyledElements */
 
-(function () {
+
+(function (utils) {
+
+    "use strict";
 
     var onFocus = function onFocus(e) {
         var range = document.createRange();
@@ -29,16 +32,31 @@
         var sel = window.getSelection();
         sel.removeAllRanges();
         sel.addRange(range);
+
+        document.addEventListener('mousedown', this._onBlur, false);
     };
 
     var onKeydown = function onKeydown(e) {
-        if (e.keyCode === 13) {
-            this.wrapperElement.blur();
+        if (e.keyCode === 13) { // enter
+            this._onBlur();
+        } else if (e.keyCode === 27) { // esc
+            this.wrapperElement.textContent = this._prev_content;
+            this._onBlur();
         }
     };
 
     var onBlur = function onBlur(e) {
-        this.events.change.dispatch(this, this.wrapperElement.textContent);
+        if (!this.wrapperElement.hasAttribute('contenteditable')) {
+            return;
+        }
+
+        document.removeEventListener('mousedown', this._onBlur, false);
+
+        var new_content = this.wrapperElement.textContent;
+        this.wrapperElement.textContent = new_content;
+        if (this._prev_content !== new_content) {
+            this.dispatchEvent('change', new_content);
+        }
         this.disableEdition();
     };
 
@@ -47,8 +65,7 @@
         StyledElements.StyledElement.call(this, ['change']);
 
         this.wrapperElement = document.createElement('span');
-
-        this.wrapperElement.textContent = options.initialContent;
+        this.setTextContent(options.initialContent);
 
         this._onFocus = onFocus.bind(this);
         this._onKeydown = onKeydown.bind(this);
@@ -58,11 +75,11 @@
         this.wrapperElement.addEventListener('keydown', this._onKeydown, true);
         this.wrapperElement.addEventListener('blur', this._onBlur, true);
     };
-    EditableElement.prototype = new StyledElements.StyledElement();
+    utils.inherit(EditableElement, StyledElements.StyledElement);
 
     EditableElement.prototype.disableEdition = function disableEdition() {
         if (this.wrapperElement.hasAttribute('contenteditable')) {
-            this.wrapperElement.removeEventListener('mousedown', Wirecloud.Utils.stopPropagationListenerfunction, true);
+            this.wrapperElement.removeEventListener('mousedown', utils.stopPropagationListener, true);
             this.wrapperElement.removeAttribute('contenteditable');
             this.wrapperElement.blur();
             this.wrapperElement.scrollLeft = 0;
@@ -72,12 +89,19 @@
 
     EditableElement.prototype.enableEdition = function enableEdition() {
         if (!this.wrapperElement.hasAttribute('contenteditable')) {
-            this.wrapperElement.addEventListener('mousedown', Wirecloud.Utils.stopPropagationListenerfunction, true);
+            this.wrapperElement.addEventListener('mousedown', utils.stopPropagationListener, true);
             this.wrapperElement.setAttribute('contenteditable', 'true');
+            this._prev_content = this.wrapperElement.textContent;
         }
         this.wrapperElement.focus();
     };
 
+    EditableElement.prototype.setTextContent = function setTextContent(textContent) {
+        this.wrapperElement.textContent = textContent;
+
+        return this;
+    };
+
     EditableElement.prototype.destroy = function destroy() {
         this.wrapperElement.removeEventListener('focus', this._onFocus, true);
         this.wrapperElement.removeEventListener('keydown', this._onKeydown, true);
@@ -92,4 +116,4 @@
 
     StyledElements.EditableElement = EditableElement;
 
-})();
+})(StyledElements.Utils);
