@@ -1,5 +1,5 @@
 /*
- *     (C) Copyright 2012 Universidad Politécnica de Madrid
+ *     Copyright 2012-2016 (c) CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,15 +19,13 @@
  *
  */
 
-/*global gettext, StyledElements, Wirecloud*/
+/* globals StyledElements, Wirecloud */
+
 
 (function () {
 
     "use strict";
 
-    /*************************************************************************
-     * Constructor
-     *************************************************************************/
     var PopUp = function PopUp(element, options) {
 
         StyledElements.ObjectWithEvents.call(this, ['close']);
@@ -35,29 +33,40 @@
         this.options = options;
 
         if (options.highlight === true) {
-            element.classList.add('tuto_highlight');
+            if (element instanceof StyledElements.StyledElement) {
+                element.addClassName('tuto_highlight');
+            } else {
+                element.classList.add('tuto_highlight');
+            }
         }
 
-        this.wrapperElement = document.createElement("div");
-        this.wrapperElement.className = 'popup alert alert-info';
+        this.wrapperElement = document.createElement('div');
+        this.wrapperElement.className = 'pop-up alert';
+
+        if (options.user) {
+            this.wrapperElement.classList.add('alert-warning');
+        } else {
+            this.wrapperElement.classList.add('alert-info');
+        }
 
         // Close button
         if (options.closable) {
-            this.cancelButton = new StyledElements.StyledButton({
-                'title': gettext("Cancel"),
-                'class': 'button icon-remove',
-                'plain': true
+            this.cancelButton = new StyledElements.Button({
+                class: 'pop-up-close',
+                iconClass: 'fa fa-remove',
+                plain: true
             });
 
             this.cancelButton.addEventListener('click', function () {
                 this.destroy();
-                this.events.close.dispatch(this);
+                this.dispatchEvent('close');
             }.bind(this));
             this.cancelButton.insertInto(this.wrapperElement);
         }
 
         // Message
-        this.textElement = document.createElement("div");
+        this.textElement = document.createElement('span');
+        this.textElement.className = 'pop-up-message';
         if (options.msg == null) {
             this.wrapperElement.classList.add("empty");
         } else {
@@ -66,14 +75,14 @@
 
         // Warning
         this.warningIco = document.createElement("span");
-        this.warningIco.className = 'warningIco icon-warning-sign';
+        this.warningIco.className = 'warningIco fa fa-warning';
         this.wrapperElement.appendChild(this.warningIco);
 
         this.wrapperElement.appendChild(this.textElement);
 
         // Arrow
-        this.arrow = document.createElement("div");
-        this.arrow.className = "popUpArrowDiv icon-hand-up";
+        this.arrow = document.createElement('span');
+        this.arrow.className = "pop-up-arrow fa fa-external-link-square";
         this.wrapperElement.appendChild(this.arrow);
 
         this.arrow.classList.add(options.position);
@@ -87,28 +96,20 @@
         switch (this.options.position) {
         default:
         case 'downRight':
-            this.wrapperElement.style.top = (pos.top + pos.height + 22) + 'px';
-            this.wrapperElement.style.left = (pos.left + pos.width + 22) + 'px';
-            this.arrow.style.top = '-28px';
-            this.arrow.style.left = '-19px';
+            this.wrapperElement.style.top = (pos.top + pos.height + 13) + 'px';
+            this.wrapperElement.style.left = (pos.left + (pos.width / 4) * 3) + 'px';
             break;
         case 'downLeft':
-            this.wrapperElement.style.top = (pos.top + pos.height + 22) + 'px';
-            this.wrapperElement.style.left = (pos.left - wrapperPos.width - 22) + 'px';
-            this.arrow.style.top = '-24px';
-            this.arrow.style.right = '-24px';
+            this.wrapperElement.style.top = (pos.top + pos.height + 13) + 'px';
+            this.wrapperElement.style.left = (pos.left - wrapperPos.width + (pos.width / 4) * 1) + 'px';
             break;
         case 'topRight':
-            this.wrapperElement.style.top = (pos.top - wrapperPos.height - 22) + 'px';
-            this.wrapperElement.style.left = (pos.left + pos.width + 20) + 'px';
-            this.arrow.style.top = (wrapperPos.height - 16) + 'px';
-            this.arrow.style.left = '-23px';
+            this.wrapperElement.style.top = (pos.top - wrapperPos.height - 13) + 'px';
+            this.wrapperElement.style.left = (pos.left + (pos.width / 4) * 3) + 'px';
             break;
         case 'topLeft':
-            this.wrapperElement.style.top = (pos.top - wrapperPos.height - 22) + 'px';
-            this.wrapperElement.style.left = (pos.left - wrapperPos.width - 31) + 'px';
-            this.arrow.style.top = (wrapperPos.height - 12) + 'px';
-            this.arrow.style.right = '-27px';
+            this.wrapperElement.style.top = (pos.top - wrapperPos.height - 13) + 'px';
+            this.wrapperElement.style.left = (pos.left - wrapperPos.width + (pos.width / 4) * 1) + 'px';
             break;
         }
     };
@@ -122,7 +123,11 @@
         }
 
         if (this.options.highlight) {
-            this.element.classList.remove('tuto_highlight');
+            if (this.element instanceof StyledElements.StyledElement) {
+                this.element.removeClassName('tuto_highlight');
+            } else {
+                this.element.classList.remove('tuto_highlight');
+            }
         }
         if (this.wrapperElement.parentNode) {
             this.wrapperElement.parentNode.removeChild(this.wrapperElement);
@@ -132,9 +137,6 @@
         this.arrow = null;
     };
 
-    /*************************************************************************
-     * Make Anchor public
-     *************************************************************************/
     Wirecloud.ui.Tutorial.PopUp = PopUp;
 
 
@@ -155,7 +157,7 @@
     };
 
     WidgetElement.prototype.getBoundingClientRect = function getBoundingClientRect() {
-        var widget_box = this.widget.content.getBoundingClientRect();
+        var widget_box = this.widget.wrapperElement.getBoundingClientRect();
         var element_box = this.element.getBoundingClientRect();
 
         return {
