@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013-2014 CoNWeT Lab., Universidad Politécnica de Madrid
+# Copyright (c) 2013-2016 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
@@ -23,6 +23,18 @@ import sys
 from django.core.urlresolvers import reverse_lazy
 
 
+BASE_APPS = (
+    'django.contrib.auth',
+    'django.contrib.contenttypes',
+    'django.contrib.sessions',
+    'django.contrib.messages',
+    'django.contrib.staticfiles',
+    'django.contrib.admin',
+    'wirecloud.commons',
+    'compressor',
+)
+
+
 class NoseArgs(object):
 
     def __init__(self, instance_type):
@@ -55,27 +67,21 @@ def load_default_wirecloud_conf(settings, instance_type='platform'):
     if 'DEBUG' not in settings:
         settings['DEBUG'] = False
 
-    settings['TEMPLATE_DEBUG'] = settings['DEBUG']
-    settings['COMPRESS'] = not settings['DEBUG']
-    settings['COMPRESS_OFFLINE'] = False
     settings['APPEND_SLASH'] = False
+
+    settings['COMPRESS_ENABLED'] = not settings['DEBUG']
+    settings['COMPRESS_OFFLINE'] = False
     settings['COMPRESS_OUTPUT_DIR'] = 'cache'
+    settings['COMPRESS_PRECOMPILERS'] = (
+        ('text/x-scss', 'wirecloud.commons.compressor_precompilers.SCSSPrecompiler'),
+    )
     settings['ALLOW_ANONYMOUS_ACCESS'] = True
+    settings['WIRECLOUD_HTTPS_VERIFY'] = True
     settings['WIRECLOUD_REMOVE_UNSUPPORTED_RESOURCES_MIGRATION'] = False
 
     settings['USE_TZ'] = True
 
-    settings['INSTALLED_APPS'] = (
-        'django.contrib.auth',
-        'django.contrib.contenttypes',
-        'django.contrib.sessions',
-        'django.contrib.messages',
-        'django.contrib.staticfiles',
-        'django.contrib.admin',
-        'wirecloud.commons',
-        'south',
-        'compressor',
-    )
+    settings['INSTALLED_APPS'] = BASE_APPS
 
     if instance_type == 'catalogue':
         settings['INSTALLED_APPS'] += (
@@ -87,10 +93,29 @@ def load_default_wirecloud_conf(settings, instance_type='platform'):
             'wirecloud.platform',
         )
 
-    settings['TEMPLATE_LOADERS'] = (
-        'wirecloud.platform.themes.load_template_source',
-        'django.template.loaders.app_directories.Loader',
-    )
+    settings['TEMPLATES'] = [
+        {
+            'BACKEND': 'django.template.backends.django.DjangoTemplates',
+            'OPTIONS': {
+                'context_processors': (
+                    'django.contrib.auth.context_processors.auth',
+                    'django.template.context_processors.debug',
+                    'django.template.context_processors.i18n',
+                    'django.template.context_processors.request',
+                    'django.template.context_processors.static',
+                    'django.template.context_processors.tz',
+                    'django.contrib.messages.context_processors.messages',
+                    'wirecloud.platform.context_processors.plugins',
+                    'wirecloud.platform.context_processors.active_theme',
+                ),
+                'debug': settings['DEBUG'],
+                'loaders': (
+                    'wirecloud.platform.themes.TemplateLoader',
+                    'django.template.loaders.app_directories.Loader',
+                )
+            }
+        }
+    ]
 
     settings['MIDDLEWARE_CLASSES'] = (
         'wirecloud.commons.middleware.URLMiddleware',
@@ -98,25 +123,31 @@ def load_default_wirecloud_conf(settings, instance_type='platform'):
 
     settings['URL_MIDDLEWARE_CLASSES'] = {
         'default': (
-            'django.middleware.gzip.GZipMiddleware',
-            'django.middleware.common.CommonMiddleware',
+            'django.middleware.security.SecurityMiddleware',
             'django.contrib.sessions.middleware.SessionMiddleware',
-            'django.middleware.locale.LocaleMiddleware',
             'wirecloud.commons.middleware.ConditionalGetMiddleware',
+            'django.middleware.common.CommonMiddleware',
+            'django.middleware.gzip.GZipMiddleware',
+            'django.middleware.locale.LocaleMiddleware',
             'django.contrib.auth.middleware.AuthenticationMiddleware',
+            'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
             'django.contrib.messages.middleware.MessageMiddleware',
         ),
         'api': (
-            'django.middleware.gzip.GZipMiddleware',
-            'django.middleware.common.CommonMiddleware',
+            'django.middleware.security.SecurityMiddleware',
             'django.contrib.sessions.middleware.SessionMiddleware',
-            'django.middleware.locale.LocaleMiddleware',
             'wirecloud.commons.middleware.ConditionalGetMiddleware',
+            'django.middleware.common.CommonMiddleware',
+            'django.middleware.gzip.GZipMiddleware',
+            'django.middleware.locale.LocaleMiddleware',
             'wirecloud.commons.middleware.AuthenticationMiddleware',
+            'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
         ),
         'proxy': (
+            'django.middleware.security.SecurityMiddleware',
             'django.contrib.sessions.middleware.SessionMiddleware',
             'django.contrib.auth.middleware.AuthenticationMiddleware',
+            'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
         )
     }
 
@@ -126,19 +157,6 @@ def load_default_wirecloud_conf(settings, instance_type='platform'):
         'compressor.finders.CompressorFinder',
     )
 
-    settings['TEMPLATE_CONTEXT_PROCESSORS'] = (
-        'django.contrib.auth.context_processors.auth',
-        'django.core.context_processors.debug',
-        'django.core.context_processors.i18n',
-        'django.core.context_processors.media',
-        'django.core.context_processors.request',
-        'django.core.context_processors.static',
-        'django.core.context_processors.tz',
-        'django.contrib.messages.context_processors.messages',
-        'wirecloud.platform.context_processors.plugins',
-        'wirecloud.platform.themes.active_theme_context_processor',
-    )
-
     settings['LOGGING'] = {
         'version': 1,
         'disable_existing_loggers': True,
@@ -148,25 +166,28 @@ def load_default_wirecloud_conf(settings, instance_type='platform'):
             },
             'require_debug_true': {
                 '()': 'wirecloud.commons.utils.log.RequireDebugTrue'
+            },
+            'skip_unreadable_posts': {
+                '()': 'wirecloud.commons.utils.log.SkipUnreadablePosts',
             }
         },
         'handlers': {
-            'console':{
+            'console': {
                 'level': 'INFO',
                 'filters': ['require_debug_true'],
                 'class': 'logging.StreamHandler',
             },
             'null': {
-                'class': 'django.utils.log.NullHandler',
+                'class': 'logging.NullHandler',
             },
             'mail_admins': {
                 'level': 'ERROR',
-                'filters': ['require_debug_false'],
+                'filters': ['require_debug_false', 'skip_unreadable_posts'],
                 'class': 'django.utils.log.AdminEmailHandler'
             }
         },
         'loggers': {
-            'django': {
+            '': {
                 'handlers': ['console'],
             },
             'django.request': {
@@ -174,16 +195,14 @@ def load_default_wirecloud_conf(settings, instance_type='platform'):
                 'level': 'ERROR',
                 'propagate': False,
             },
-            'py.warnings': {
-                'handlers': ['console'],
-            },
-            'rdflib': {
-                'handlers': ['console'],
-            },
         }
     }
 
     settings['LOGIN_REDIRECT_URL'] = reverse_lazy('wirecloud.root')
     settings['LOGOUT_REDIRECT_URL'] = reverse_lazy('wirecloud.root')
 
+    settings['CATALOGUE_MEDIA_ROOT'] = os.path.join(settings['BASEDIR'], 'catalogue', 'media')
+    settings['GADGETS_DEPLOYMENT_DIR'] = os.path.join(settings['BASEDIR'], 'deployment', 'widgets')
+    settings['WIRECLOUD_INDEX_DIR'] = os.path.join(settings['BASEDIR'], 'index')
+
     settings['NOSE_ARGS'] = NoseArgs(instance_type)
