@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
+# Copyright (c) 2012-2015 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
@@ -17,10 +17,13 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import unicode_literals
+
 import codecs
+from django.utils.translation import ugettext as _
 import platform
 import requests
-from urlparse import urlparse
+from six.moves.urllib.parse import urlparse
 
 import wirecloud.platform
 
@@ -35,18 +38,15 @@ VERSIONS = {
 
 def download_local_file(path):
 
-    f = codecs.open(path, 'rb')
-    contents = f.read()
-    f.close()
-
-    return contents
+    with codecs.open(path, 'rb') as f:
+        return f.read()
 
 
 def download_http_content(url, user=None):
 
     parsed_url = urlparse(url)
     if parsed_url.scheme not in ('http', 'https'):
-        return ''
+        raise requests.exceptions.InvalidSchema(_('Invalid schema: %(schema)s') % {"schema": parsed_url.scheme})
 
     headers = {
         'User-Agent': 'Mozilla/5.0 (%(system)s %(machine)s;U) Wirecloud/%(wirecloud_version)s python-requests/%(requests_version)s' % VERSIONS,
@@ -55,9 +55,6 @@ def download_http_content(url, user=None):
         'Accept-Charset': 'utf-8;q=1,*;q=0.2',
     }
 
-    if user and not user.is_anonymous():
-        headers.update({
-            'Remote-User': user.username,
-        })
-
-    return requests.get(url, headers=headers).content
+    response = requests.get(url, headers=headers)
+    response.raise_for_status()
+    return response.content
