@@ -1,9 +1,10 @@
 import re
+import six
 
 
 def get_trans_index(value):
     """Checks if the string received as argument is a translation index"""
-    if type(value).__name__ == "str" or type(value).__name__ == "unicode":
+    if isinstance(value, six.string_types):
         index = re.match("__MSG_(?P<value>.+)__", value, re.I)
         if index:
             return index.group("value")
