@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012-2013 CoNWeT Lab., Universidad Politécnica de Madrid
+# Copyright (c) 2012-2017 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
@@ -22,12 +22,15 @@ from django.db import models
 from django.utils.encoding import python_2_unicode_compatible
 from django.utils.translation import ugettext as _
 
+from wirecloud.commons.fields import JSONField
+
 
 @python_2_unicode_compatible
 class Market(models.Model):
-    user = models.ForeignKey(User, verbose_name=_('User'), blank=True, null=True)
+    user = models.ForeignKey(User, on_delete=models.CASCADE, verbose_name=_('User'), blank=True)
     name = models.CharField(_('Name'), max_length=50)
-    options = models.TextField(_('Options'))
+    public = models.BooleanField(_('Public'), default=False)
+    options = JSONField(_('Options'))
 
     class Meta:
         unique_together = ('user', 'name')
@@ -35,17 +38,14 @@ class Market(models.Model):
         db_table = 'wirecloud_market'
 
     def __str__(self):
-        if self.user is None:
-            return self.name
-        else:
-            return self.user.username + '/' + self.name
+        return self.user.username + '/' + self.name
 
 
 @python_2_unicode_compatible
 class MarketUserData(models.Model):
 
-    market = models.ForeignKey(Market, verbose_name=_('Market'), blank=False, null=False)
-    user = models.ForeignKey(User, verbose_name=_('User'), blank=False, null=False)
+    market = models.ForeignKey(Market, on_delete=models.CASCADE, verbose_name=_('Market'), blank=False, null=False)
+    user = models.ForeignKey(User, on_delete=models.CASCADE, verbose_name=_('User'), blank=False, null=False)
     name = models.CharField(_('Name'), max_length=50)
     value = models.CharField(_('Value'), max_length=250)
 
