@@ -1,5 +1,5 @@
 /*
- *     Copyright (c) 2012 CoNWeT Lab., Universidad Politécnica de Madrid
+ *     Copyright (c) 2012-2015 CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,17 +19,26 @@
  *
  */
 
-/*global MashupPlatform*/
+/* globals MashupPlatform */
+
 
 (function () {
 
     "use strict";
 
-    // Remove reference to the internal wirecloud resource
-    delete MashupPlatform.resource;
+    // Remove reference to the private dict, removing also the reference to the
+    // internal wirecloud resource
+    delete MashupPlatform.priv;
 
+    Object.preventExtensions(MashupPlatform.mashup);
     Object.preventExtensions(MashupPlatform);
 
+    if ('widget' in MashupPlatform) {
+        Object.preventExtensions(MashupPlatform.widget);
+    } else {
+        Object.preventExtensions(MashupPlatform.operator);
+    }
+
     // Remove link to wirecloud
     window.parent = window;
 
