@@ -1,5 +1,5 @@
 /*
- *     Copyright (c) 2013-2014 CoNWeT Lab., Universidad Politécnica de Madrid
+ *     Copyright (c) 2013-2017 CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,7 +19,8 @@
  *
  */
 
-/*global Wirecloud*/
+/* globals Wirecloud */
+
 
 (function () {
 
@@ -28,6 +29,10 @@
     var check_basic_requirements = function check_basic_requirements() {
         var tester = {};
 
+        if (!('addEventListener' in document.documentElement)) {
+            throw new Error('Missing basic DOM event support');
+        }
+
         if (!('JSON' in window)) {
             throw new Error('Missing JSON support');
         }
@@ -36,6 +41,10 @@
             throw new Error('Missing Object.freeze support');
         }
 
+        if (!('create' in Object)) {
+            throw new Error('Missing Object.create support');
+        }
+
         if (!('defineProperty' in Object)) {
             throw new Error('Missing Object.defineProperty support');
         }
@@ -66,6 +75,20 @@
         if (!('pointerEvents' in document.documentElement.style)) {
             throw new Error('Missing pointer-events support for HTML elements');
         }
+
+        if (!('Promise' in window)) {
+            throw new Error('Missing Promise support');
+        }
+
+        if (!('WeakMap' in window)) {
+            throw new Error('Missing WeakMap support');
+        }
+
+        try {
+            eval("var bar = (x) => x+1");
+        } catch (e) {
+            throw new Error('Missing arrow functions support');
+        }
     };
 
     Wirecloud.check_basic_requirements = check_basic_requirements;
