@@ -1,5 +1,5 @@
 /*
- *     Copyright (c) 2012-2013 CoNWeT Lab., Universidad Politécnica de Madrid
+ *     Copyright (c) 2012-2017 CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,6 +19,9 @@
  *
  */
 
+/* globals Wirecloud */
+
+
 (function () {
 
     "use strict";
@@ -26,32 +29,36 @@
     /**
      * @author aarranz
      */
-    var UserPrefDef = function UserPrefDef(name, type, options) {
+    var UserPrefDef = function UserPrefDef(options) {
+
+        if (options == null || typeof options !== "object") {
+            throw new TypeError('Invalid options parameter');
+        }
 
         if (options.default != null && typeof options.default !== "string") {
             throw new TypeError('Invalid default option');
         }
 
-        if (type === 'list') {
-            type = 'select';
+        if (options.type === 'list') {
+            options.type = 'select';
         }
 
-        // the value option is only used on the server side
-        if ('value' in options) {
-            delete options.value;
-        }
-
-        Object.defineProperty(this, 'name', {value: name});
-        Object.defineProperty(this, 'type', {value: type});
-        Object.defineProperty(this, 'label', {value: options.label});
-        Object.defineProperty(this, 'description', {value: options.description});
-        Object.defineProperty(this, 'options', {value: options});
+        Object.defineProperties(this, {
+            name: {value: options.name},
+            type: {value: options.type},
+            label: {value: options.label},
+            description: {value: options.description},
+            required: {value: options.required},
+            options: {value: options.options}
+        });
 
         var default_value = '';
-        if (options.type !== 'boolean' && options.default != null) {
-            default_value = options.default;
-        } else if (options.type === 'boolean') {
+        if (options.type === 'boolean') {
             default_value = options.default.trim().toLowerCase() === 'true';
+        } else if (options.type === 'number' && options.default != null) {
+            default_value = Number(options.default);
+        } else if (options.default != null) {
+            default_value = options.default;
         }
         Object.defineProperty(this, 'default', {value: default_value});
     };
