@@ -1,5 +1,5 @@
 /*
- *     Copyright (c) 2008-2013 CoNWeT Lab., Universidad Politécnica de Madrid
+ *     Copyright (c) 2008-2015 CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,7 +19,8 @@
  *
  */
 
-/*global gettext, Wirecloud*/
+/* globals Wirecloud */
+
 
 (function () {
 
@@ -54,7 +55,7 @@
         } else if ((_matrix[x][y - 1] != null) && (_matrix[x][y - 1] != _matrix[x][y])) {
             return y;
         } else if (_matrix[x][y]) {
-            widthDiff = _matrix[x][y].getWidth() - width;
+            widthDiff = _matrix[x][y].shape.width - width;
             widthDiff -= x - this._getPositionOn(_matrix, _matrix[x][y]).x;
             if (widthDiff > 0) {
                 // The widget at (x,y) has the same or a bigger width
@@ -121,49 +122,19 @@
         return this.searchInsertPointCache[x][y];
     };
 
-    SmartColumnLayout.prototype.moveTemporally = function (x, y) {
-        if (this.iwidgetToMove == null) {
-            var msg = gettext("Dragboard: You must call initializeMove function before calling to this function (moveTemporally).");
-            Wirecloud.GlobalLogManager.log(msg, Wirecloud.constants.LOGGING.WARN_MSG);
-            return;
-        }
-
-        var maxX = this.getColumns() - this.iwidgetToMove.getWidth();
-        if (x > maxX) {
-            x = maxX;
-        }
-
-        // Check if we have to change the position of the cursor
-        y = this._searchInsertPoint(this.shadowMatrix, x, y, this.iwidgetToMove.getWidth(), this.iwidgetToMove.getHeight());
-
-        if (this.dragboardCursor !== null) {
-            var cursorpos = this.dragboardCursor.getPosition();
-
-            if ((cursorpos.y !== y) || (cursorpos.x !== x)) {
-                // Change cursor position
-                this._removeFromMatrix(this.matrix, this.dragboardCursor);
-                this._insertAt(this.dragboardCursor, x, y);
-            }
-        } else {
-            this.dragboardCursor = new Wirecloud.ui.DragboardCursor(this.iwidgetToMove);
-            this.dragboardCursor.paint(this.dragboard.dragboardElement);
-            this._insertAt(this.dragboardCursor, x, y);
-        }
-    };
-
     SmartColumnLayout.prototype.initialize = function () {
         var modified = Wirecloud.ui.ColumnLayout.prototype.initialize.call(this);
 
         // remove holes moving iwidgets to the topmost positions
-        var iWidget, key, keys = [];
-        for (key in this.iWidgets) {
+        var widget, key, keys = [];
+        for (key in this.widgets) {
             keys.push(key);
-            iWidget = this.iWidgets[key];
-            modified = modified || this._moveSpaceUp(this.matrix, iWidget);
+            widget = this.widgets[key];
+            modified = modified || this._moveSpaceUp("base", widget);
         }
         if (modified) {
-            //save these changes in the server side
-            this.dragboard._commitChanges(keys);
+            // save these changes in the server side
+            this.dragboard.update(keys);
         }
     };
 
@@ -173,10 +144,10 @@
         }
     };
 
-    SmartColumnLayout.prototype._notifyResizeEvent = function (iWidget, oldWidth, oldHeight, newWidth, newHeight, resizeLeftSide, persist) {
+    SmartColumnLayout.prototype._notifyResizeEvent = function (widget, oldWidth, oldHeight, newWidth, newHeight, resizeLeftSide, persist) {
         var x, y;
         var step2Width = oldWidth; // default value, used when the igdaget's width doesn't change
-        var position = iWidget.getPosition();
+        var position = widget.position;
         var step2X, finalYPos, widthDiff, iWidgetToMove, limitX, limitY;
         step2X = position.x;
 
@@ -194,7 +165,7 @@
                     for (y = 0; y < newHeight; ++y) {
                         iWidgetToMove = this.matrix[x][position.y + y];
                         if (iWidgetToMove != null) {
-                            this._moveSpaceDown(this.matrix, iWidgetToMove, finalYPos - iWidgetToMove.position.y);
+                            this._moveSpaceDown("base", iWidgetToMove, finalYPos - iWidgetToMove.position.y);
                             break; // Continue with the next column
                         }
                     }
@@ -202,12 +173,10 @@
 
                 // Move the widget
                 position.x -= widthDiff;
-                if (persist) {
-                    iWidget.setPosition(position);
-                }
+                widget.setPosition(position);
 
                 // Reserve the new space
-                this._reserveSpace2(this.matrix, iWidget,
+                this._reserveSpace2(this.matrix, widget,
                                                  position.x, position.y,
                                                  widthDiff, newHeight);
             } else {
@@ -216,14 +185,14 @@
                     for (y = 0; y < newHeight; ++y) {
                         iWidgetToMove = this.matrix[x][position.y + y];
                         if (iWidgetToMove != null) {
-                            this._moveSpaceDown(this.matrix, iWidgetToMove, finalYPos - iWidgetToMove.position.y);
+                            this._moveSpaceDown("base", iWidgetToMove, finalYPos - iWidgetToMove.position.y);
                             break; // Continue with the next column
                         }
                     }
                 }
 
                 // Reserve this space
-                this._reserveSpace2(this.matrix, iWidget,
+                this._reserveSpace2(this.matrix, widget,
                                                  position.x + oldWidth, position.y,
                                                  newWidth - oldWidth, newHeight);
             }
@@ -243,15 +212,13 @@
                 limitX = position.x + widthDiff;
                 for (x = position.x; x < limitX; ++x) {
                     if (this.matrix[x][y] != null) {
-                        this._moveSpaceUp(this.matrix, this.matrix[x][y]);
+                        this._moveSpaceUp("base", this.matrix[x][y]);
                     }
                 }
 
                 // Move the widget
                 position.x += widthDiff;
-                if (persist) {
-                    iWidget.setPosition(position);
-                }
+                widget.setPosition(position);
 
                 step2X = position.x;
             } else {
@@ -263,7 +230,7 @@
                 limitX = position.x + oldWidth;
                 for (x = position.x + newWidth; x < limitX; ++x) {
                     if (this.matrix[x][y] != null) {
-                        this._moveSpaceUp(this.matrix, this.matrix[x][y]);
+                        this._moveSpaceUp("base", this.matrix[x][y]);
                     }
                 }
             }
@@ -276,13 +243,13 @@
             for (y = position.y + oldHeight; y < limitY; y++) {
                 for (x = step2X; x < limitX; x++) {
                     if (this.matrix[x][y] != null) {
-                        this._moveSpaceDown(this.matrix, this.matrix[x][y], limitY - y);
+                        this._moveSpaceDown("base", this.matrix[x][y], limitY - y);
                     }
                 }
             }
 
             // Reserve Space
-            this._reserveSpace2(this.matrix, iWidget, step2X, position.y + oldHeight, step2Width, newHeight - oldHeight);
+            this._reserveSpace2(this.matrix, widget, step2X, position.y + oldHeight, step2Width, newHeight - oldHeight);
         } else if (newHeight < oldHeight) {
             // Clear freed space
             this._clearSpace2(this.matrix, step2X, position.y + newHeight, step2Width, oldHeight - newHeight);
@@ -291,47 +258,50 @@
             limitX = step2X + step2Width;
             for (x = step2X; x < limitX; x++) {
                 if (this.matrix[x][y] != null) {
-                    this._moveSpaceUp(this.matrix, this.matrix[x][y]);
+                    this._moveSpaceUp("base", this.matrix[x][y]);
                 }
             }
         }
 
         this._notifyWindowResizeEvent(true, true); // TODO
         if (persist) {
-            this._moveSpaceUp(this.matrix, iWidget);
+            this._moveSpaceUp("base", widget);
             // Save new positions into persistence
-            this.dragboard._commitChanges(); // FIXME
+            this.dragboard.update(); // FIXME
         }
     };
 
-    //Returns if any widget's position has been modified
-    SmartColumnLayout.prototype._insertAt = function (iWidget, x, y) {
+    // Returns if any widget's position has been modified
+    SmartColumnLayout.prototype._insertAt = function (widget, x, y, buffer) {
 
-        var affectedWidgets = Wirecloud.ui.ColumnLayout.prototype._insertAt.call(this, iWidget, x, y);
-
-        this._moveSpaceUp(this.matrix, iWidget);
+        var affectedWidgets = Wirecloud.ui.ColumnLayout.prototype._insertAt.call(this, widget, x, y, buffer);
+        this._moveSpaceUp(buffer, widget);
 
         return affectedWidgets;
     };
 
-    //Returns if any widget's position has been modified
-    SmartColumnLayout.prototype._removeFromMatrix = function (_matrix, iWidget) {
-        this._clearSpace(_matrix, iWidget);
+    /**
+     * @returns Returns true if any widget's position has been modified
+     */
+    SmartColumnLayout.prototype._removeFromMatrix = function (buffer, widget) {
+        this._clearSpace(buffer, widget);
 
         var modified = false, affectedIWidgets = {};
         var affectedwidget, x, y, columnsize;
-        var position = this._getPositionOn(_matrix, iWidget);
-        var edgeY = position.y + iWidget.getHeight();
+        var position = this._getPositionOn(buffer, widget);
+        var edgeY = position.y + widget.shape.height;
+
+        var _matrix = this._buffers[buffer].matrix;
 
         // check if we have to update the representations of the widget instances
-        for (x = 0; x < iWidget.getWidth(); x++) {
+        for (x = 0; x < widget.shape.width; x++) {
             columnsize = _matrix[position.x + x].length;
             for (y = edgeY; y < columnsize; y++) {
                 affectedwidget = _matrix[position.x + x][y];
-                if ((affectedwidget != null) && (typeof affectedIWidgets[affectedwidget.code] !== true)) {
-                    affectedIWidgets[affectedwidget.code] = true;
+                if ((affectedwidget != null) && (typeof affectedIWidgets[affectedwidget.id] !== true)) {
+                    affectedIWidgets[affectedwidget.id] = true;
                     modified = true;
-                    this._moveSpaceUp(_matrix, affectedwidget);
+                    this._moveSpaceUp(buffer, affectedwidget);
                     break;
                 }
             }
