@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
+# Copyright (c) 2012-2016 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
@@ -19,10 +19,11 @@
 
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
-from django.utils.unittest import TestCase
+from django.test import TestCase
+from mock import DEFAULT, patch
 
 from wirecloud.platform.plugins import clear_cache, get_active_features, get_plugins, \
-    get_extra_javascripts, get_widget_api_extensions, WirecloudPlugin
+    get_extra_javascripts, get_widget_api_extensions, WirecloudPlugin, find_wirecloud_plugins
 
 
 # Avoid nose to repeat these tests (they are run through wirecloud/platform/tests/__init__.py)
@@ -65,11 +66,17 @@ class WirecloudTestConflictingPlugin(WirecloudPlugin):
 
 class WirecloudPluginTestCase(TestCase):
 
+    tags = ('wirecloud-plugins',)
+
     @classmethod
     def setUpClass(cls):
         cls.OLD_WIRECLOUD_PLUGINS = getattr(settings, 'WIRECLOUD_PLUGINS', None)
         super(WirecloudPluginTestCase, cls).setUpClass()
 
+    def setUp(self):
+        super(WirecloudPluginTestCase, self).setUp()
+        clear_cache()
+
     def tearDown(self):
         settings.WIRECLOUD_PLUGINS = self.OLD_WIRECLOUD_PLUGINS
         clear_cache()
@@ -78,7 +85,6 @@ class WirecloudPluginTestCase(TestCase):
     def test_basic_conf(self):
 
         settings.WIRECLOUD_PLUGINS = ()
-        clear_cache()
 
         core_plugins = len(get_plugins())
         core_features = len(get_active_features())
@@ -100,11 +106,53 @@ class WirecloudPluginTestCase(TestCase):
         self.assertEqual(len(get_widget_api_extensions('classic', {})), core_classic_extensions + 1)
         self.assertEqual(len(get_widget_api_extensions('smartphone', {})), core_smartphone_extensions + 0)
 
+    def test_inexistent_module(self):
+
+        settings.WIRECLOUD_PLUGINS = ('inexistent.module.WirecloudTestPlugin1',)
+
+        self.assertRaises(ImproperlyConfigured, get_plugins)
+
+    def test_inexistent_plugin(self):
+
+        settings.WIRECLOUD_PLUGINS = ('wirecloud.platform.tests.plugins.InexistentWirecloudTestPlugin',)
+
+        self.assertRaises(ImproperlyConfigured, get_plugins)
+
+    def test_invalid_plugin_entry(self):
+
+        settings.WIRECLOUD_PLUGINS = (5,)
+
+        self.assertRaises(ImproperlyConfigured, get_plugins)
+
     def test_several_plugins_with_the_same_feature(self):
+
         settings.WIRECLOUD_PLUGINS = (
             'wirecloud.platform.tests.plugins.WirecloudTestPlugin1',
             'wirecloud.platform.tests.plugins.WirecloudTestConflictingPlugin',
         )
-        clear_cache()
 
         self.assertRaises(ImproperlyConfigured, get_plugins)
+
+    def test_find_wirecloud_plugins_app_with_extra_import_errors(self):
+
+        with self.settings(INSTALLED_APPS=('wirecloud.platform.tests.module_with_errors',)):
+            with patch.multiple('wirecloud.platform.plugins', logger=DEFAULT, import_module=DEFAULT) as mocks:
+                mocks['import_module'].side_effect = ImportError('No module named x')
+                find_wirecloud_plugins()
+                self.assertTrue(mocks['logger'].error.called)
+
+    def test_find_wirecloud_plugins_app_with_syntax_errors(self):
+
+        with self.settings(INSTALLED_APPS=('wirecloud.platform.tests.module_with_errors',)):
+            with patch.multiple('wirecloud.platform.plugins', logger=DEFAULT, import_module=DEFAULT) as mocks:
+                mocks['import_module'].side_effect = SyntaxError()
+                find_wirecloud_plugins()
+                self.assertTrue(mocks['logger'].error.called)
+
+    def test_find_wirecloud_plugins_app_with_name_errors(self):
+
+        with self.settings(INSTALLED_APPS=('wirecloud.platform.tests.module_with_errors',)):
+            with patch.multiple('wirecloud.platform.plugins', logger=DEFAULT, import_module=DEFAULT) as mocks:
+                mocks['import_module'].side_effect = NameError()
+                find_wirecloud_plugins()
+                self.assertTrue(mocks['logger'].error.called)
