@@ -1,4 +1,5 @@
-from django.utils.importlib import import_module
+from importlib import import_module
+
 from django.core.exceptions import ImproperlyConfigured
 
 
@@ -10,7 +11,7 @@ def get_workspace_managers():
     global _ezweb_workspace_managers
 
     if _ezweb_workspace_managers is None:
-        if hasattr(settings, 'WORKSPACE_MANAGERS') and settings.WORKSPACE_MANAGERS != None:
+        if hasattr(settings, 'WORKSPACE_MANAGERS') and settings.WORKSPACE_MANAGERS is not None:
             managers = settings.WORKSPACE_MANAGERS
         else:
             managers = ()
