@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011-2014 CoNWeT Lab., Universidad Politécnica de Madrid
+# Copyright (c) 2011-2017 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
@@ -17,10 +17,10 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
-from django.http import HttpResponse
+from wirecloud.commons.utils.http import build_error_response
 
 
-# hop-by-hop headers(http://www.w3.org/Protocols/rfc2616/rfc2616-sec13.html#sec13.5.1)
+# Remove hop-by-hop headers (http://www.w3.org/Protocols/rfc2616/rfc2616-sec13.html#sec13.5.1)
 BLACKLISTED_HEADERS = {
     'connection': 1, 'keep-alive': 1, 'proxy-authenticate': 1,
     'proxy-authorization': 1, 'te': 1, 'trailers': 1, 'transfer-encoding': 1,
@@ -33,9 +33,9 @@ class ValidationError(Exception):
     def __init__(self, msg):
         self.msg = msg
 
-    def get_response(self):
-        return HttpResponse(self.msg, status=422)
+    def get_response(self, request):
+        return build_error_response(request, 422, self.msg)
 
 
 def is_valid_response_header(header):
-    return not header in BLACKLISTED_HEADERS
+    return header not in BLACKLISTED_HEADERS
